aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorArthur Schiwon <blizzz@arthur-schiwon.de>2017-05-26 13:44:43 +0200
committerArthur Schiwon <blizzz@arthur-schiwon.de>2017-05-26 13:44:43 +0200
commitb79f9cadc2e4a459a60a421f7e6a6ea02324780c (patch)
tree73252b97313b1848e1ed33ee1328f66985ecc298
parentbd5d12528f1bdf6ab25dda5179ea20a56916a3a2 (diff)
downloadnextcloud-server-b79f9cadc2e4a459a60a421f7e6a6ea02324780c.tar.gz
nextcloud-server-b79f9cadc2e4a459a60a421f7e6a6ea02324780c.zip
fix paging
Signed-off-by: Arthur Schiwon <blizzz@arthur-schiwon.de>
-rw-r--r--apps/user_ldap/lib/Access.php7
1 files changed, 4 insertions, 3 deletions
diff --git a/apps/user_ldap/lib/Access.php b/apps/user_ldap/lib/Access.php
index 9293ae786bf..f342785ee03 100644
--- a/apps/user_ldap/lib/Access.php
+++ b/apps/user_ldap/lib/Access.php
@@ -956,10 +956,11 @@ class Access extends LDAPUtility implements IUserTools {
}
array_unshift($arguments, $cr);
// php no longer supports call-time pass-by-reference
// make special case for controlPagedResultResponse as the third argument is a reference
$doMethod = function () use ($command, &$arguments) {
if ($command == 'controlPagedResultResponse') {
- return $this->ldap->controlPagedResultResponse($arguments[0], $arguments[1], $arguments[2]);
+ throw new \InvalidArgumentException('Invoker does not support controlPagedResultResponse, call LDAP Wrapper directly instead.');
} else {
return call_user_func_array(array($this->ldap, $command), $arguments);
}
@@ -1042,7 +1043,7 @@ class Access extends LDAPUtility implements IUserTools {
if($pagedSearchOK) {
$cr = $this->connection->getConnectionResource();
foreach($sr as $key => $res) {
- if($this->invokeLDAPMethod('controlPagedResultResponse', $cr, $res, $cookie)) {
+ if($this->ldap->controlPagedResultResponse($cr, $res, $cookie)) {
$this->setPagedResultCookie($base[$key], $filter, $limit, $offset, $cookie);
}
}
@@ -956,10 +956,11 @@ class Access extends LDAPUtility implements IUserTools {
array_unshift($arguments, $cr);
// php no longer supports call-time pass-by-reference
- // make special case for controlPagedResultResponse as the third argument is a reference
+ // thus cannot support controlPagedResultResponse as the third argument
+ // is a reference
$doMethod = function () use ($command, &$arguments) {
if ($command == 'controlPagedResultResponse') {